@@ -3,6 +3,7 @@ from sklearn.base import BaseEstimator, ClassifierMixin, RegressorMixin
 from sklearn.pipeline import Pipeline
 
 import numpy
+import warnings
 
 class _Verification(object):
 
@@ -63,10 +64,15 @@ class PMMLPipeline(Pipeline):
 		active_fields = _get_column_names(X)
 		if active_fields is not None:
 			self.active_fields = active_fields
+		else:
+			warnings.warn("X is missing feature names. The reproducibility of predictions between Scikit-Learn and PMML can not be guaranteed")
 		# Collect label name(s)
 		target_fields = _get_column_names(y)
 		if target_fields is not None:
 			self.target_fields = target_fields
+		else:
+			if y is not None:
+				warnings.warn("y is missing target field name(s)")
 		return super(PMMLPipeline, self)._fit(X = X, y = y, **fit_params)
 
 	def _transform(self, X):
